@@ -25,9 +25,6 @@
 
 /*----------------------------------------------------------------------------*/
 
-#include <libecal/e-cal.h>
-#include <libedata-cal/e-data-cal-types.h>
-
 #include <libekolabutil/camel-system-headers.h>
 #include <libekolab/kolab-settings-handler.h>
 #include <libekolab/kolab-mail-access.h>
@@ -42,11 +39,9 @@ kolab_util_calendar_create_http_request (KolabSettingsHandler *ksettings,
                                          const gchar *path,
                                          GError **error)
 {
-	CamelURL *uri = NULL;
-	const gchar *url = NULL;
-	const gchar *user = NULL;
+	CamelURL *url = NULL;
+	CamelKolabIMAPXSettings *settings;
 	const gchar *passwd = NULL;
-	guint tls_variant = KOLAB_TLS_VARIANT_DEFAULT;
 	KolabUtilHttpJob *job = NULL;
 	GError *tmp_err = NULL;
 
@@ -54,46 +49,10 @@ kolab_util_calendar_create_http_request (KolabSettingsHandler *ksettings,
 	g_assert (path != NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-	url = kolab_settings_handler_get_char_field (ksettings,
-	                                             KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_URI,
-	                                             &tmp_err);
-	if (url == NULL) {
-		g_propagate_error (error, tmp_err);
-		return NULL;
-	}
-	tls_variant = kolab_settings_handler_get_uint_field (ksettings,
-	                                                     KOLAB_SETTINGS_HANDLER_UINT_FIELD_TLS_VARIANT,
-	                                                     &tmp_err);
-	if (tmp_err != NULL) {
-		g_propagate_error (error, tmp_err);
-		return NULL;
-	}
-	uri = camel_url_new (url, &tmp_err);
-	if (tmp_err != NULL) {
-		g_propagate_error (error, tmp_err);
-		return NULL;
-	}
-	if (uri == NULL) {
-		/* FIXME is this an error condition? */
-		return NULL;
-	}
-	switch (tls_variant) {
-	case KOLAB_TLS_VARIANT_NONE:
-		camel_url_set_protocol (uri, "http");
-		break;
-	default:
-		camel_url_set_protocol (uri, "https");
-	}
-	camel_url_set_path (uri, path);
-	user = kolab_settings_handler_get_char_field (ksettings,
-	                                              KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_NAME,
-	                                              &tmp_err);
-	if (user == NULL) {
-		g_propagate_error (error, tmp_err);
-		camel_url_free (uri);
-		return NULL;
-	}
-	camel_url_set_user (uri, user);
+	settings = kolab_settings_handler_get_camel_settings (ksettings);
+	url = camel_kolab_imapx_settings_build_url (settings);
+	camel_url_set_path (url, path);
+
 	passwd = kolab_settings_handler_get_char_field (ksettings,
 	                                                KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_PASSWORD,
 	                                                &tmp_err);
@@ -104,7 +63,7 @@ kolab_util_calendar_create_http_request (KolabSettingsHandler *ksettings,
 	}
 
 	job = kolab_util_http_job_new ();
-	job->url = uri;
+	job->url = url;
 	job->passwd = g_strdup (passwd); /* no longer carried by CamelURL */
 
 	return job;
@@ -115,6 +74,8 @@ kolab_util_calendar_create_pfb_trigger (KolabSettingsHandler *ksettings,
                                         const gchar *sourcename,
                                         GError **error)
 {
+	CamelKolabIMAPXSettings *camel_settings;
+	CamelNetworkSettings *network_settings;
 	KolabUtilHttpJob *job = NULL;
 	gchar *path = NULL;
 	const gchar *username = NULL;
@@ -125,13 +86,10 @@ kolab_util_calendar_create_pfb_trigger (KolabSettingsHandler *ksettings,
 	g_assert (sourcename != NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-	username = kolab_settings_handler_get_char_field (ksettings,
-	                                                  KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_NAME,
-	                                                  &tmp_err);
-	if (tmp_err != NULL) {
-		g_propagate_error (error, tmp_err);
-		return NULL;
-	}
+	camel_settings = kolab_settings_handler_get_camel_settings (ksettings);
+
+	network_settings = CAMEL_NETWORK_SETTINGS (camel_settings);
+	username = camel_network_settings_get_user (network_settings);
 
 	if (strncmp (username, "INBOX/", 6))
 		source_offset = 6;
@@ -302,12 +260,12 @@ gboolean
 kolab_util_calendar_store (ECalComponent *ecalcomp,
                            ECalComponent *ecaltz,
                            ECalComponent *default_tz,
+                           ECalBackendSync *backend,
                            KolabMailAccess *koma,
-                           const gchar *uri,
                            GCancellable *cancellable,
                            GError **error)
 {
-	gchar *sourcename = NULL;
+	const gchar *foldername;
 	KolabMailHandle *kmh = NULL;
 	KolabSettingsHandler *ksettings = NULL;
 	KolabMailAccessOpmodeID mode = KOLAB_MAIL_ACCESS_OPMODE_INVAL;
@@ -318,8 +276,8 @@ kolab_util_calendar_store (ECalComponent *ecalcomp,
 	g_assert (E_IS_CAL_COMPONENT (ecalcomp));
 	/* ecaltz may be NULL */
 	(void)default_tz; /* FIXME needed? */ /* default_tz may be NULL */
+	g_assert (E_IS_CAL_BACKEND_SYNC (backend));
 	g_assert (KOLAB_IS_MAIL_ACCESS (koma));
-	g_assert (uri != NULL);
 	/* cancellable may be NULL */
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
@@ -329,14 +287,14 @@ kolab_util_calendar_store (ECalComponent *ecalcomp,
 		return FALSE;
 	}
 
-	sourcename = kolab_util_backend_get_relative_path_from_uri (uri);
+	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 
 	kolab_util_backend_modtime_set_on_ecalcomp (ecalcomp);
 	kmh = kolab_mail_handle_new_from_ecalcomponent (ecalcomp,
 	                                                ecaltz);
 	ok =  kolab_mail_access_store_handle (koma,
 	                                      kmh,
-	                                      sourcename,
+	                                      foldername,
 	                                      cancellable,
 	                                      &tmp_err);
 	if (! ok)
@@ -354,14 +312,14 @@ kolab_util_calendar_store (ECalComponent *ecalcomp,
 	}
 
 	do_trigger = kolab_mail_access_source_fbtrigger_needed (koma,
-	                                                        sourcename,
+	                                                        foldername,
 	                                                        &tmp_err);
 	if (tmp_err != NULL)
 		goto cleanup;
 
 	if (do_trigger == TRUE) {
 		(void) kolab_util_calendar_toggle_pfb_trigger (ksettings,
-		                                               sourcename,
+		                                               foldername,
 		                                               &tmp_err);
 		if (tmp_err != NULL) {
 			/* if triggering the XFB generation fails,
@@ -377,7 +335,6 @@ kolab_util_calendar_store (ECalComponent *ecalcomp,
 
  cleanup:
 	g_object_unref (ksettings);
-	g_free (sourcename);
 	if (tmp_err != NULL) {
 		g_propagate_error (error, tmp_err);
 		return FALSE;
