@@ -33,8 +33,8 @@
 #include <gio/gio.h>
 
 #include <libical/icalcomponent.h>
-#include <libecal/e-cal.h>
-#include <libedata-cal/e-cal-backend-sync.h>
+#include <libecal/libecal.h>
+#include <libedata-cal/libedata-cal.h>
 
 #include <libekolabutil/kolab-util-http.h>
 #include <libekolab/kolab-settings-handler.h>
@@ -70,8 +70,8 @@ gboolean
 kolab_util_calendar_store (ECalComponent *ecalcomp,
                            ECalComponent *ecaltz,
                            ECalComponent *default_tz,
+                           ECalBackendSync *backend,
                            KolabMailAccess *koma,
-                           const gchar *uri,
                            GCancellable *cancellable,
                            GError **error);
 
