@@ -30,7 +30,7 @@
 
 #include <glib/gi18n-lib.h>
 
-#include <libedataserverui/e-source-selector.h>
+#include <libedataserverui/libedataserverui.h>
 
 #include <e-util/e-util.h>
 #include <e-util/e-dialog-utils.h>
@@ -125,6 +125,7 @@ struct _KolabFolderPropUIData {
 	KolabFolderPermUIData *perm_ui_data;
 	KolabDataImapAccount *account;
 	gchar *selected_folder;
+	gchar *selected_source;
 };
 
 static void
@@ -149,6 +150,7 @@ kolab_folder_prop_ui_data_new ()
 	uidata->perm_ui_data = NULL;
 	uidata->account = NULL;
 	uidata->selected_folder = NULL;
+	uidata->selected_source = NULL;
 
 	return uidata;
 }
@@ -170,6 +172,8 @@ kolab_folder_prop_ui_data_free (KolabFolderPropUIData *uidata)
 	kolab_data_imap_account_free (uidata->account);
 	if (uidata->selected_folder != NULL)
 		g_free (uidata->selected_folder);
+	if (uidata->selected_source != NULL)
+		g_free (uidata->selected_source);
 
 	g_free (uidata);
 }
@@ -393,7 +397,9 @@ kolab_plugin_ui_action_kolab_properties_cb (GtkAction *action,
 	GObject *dialog = NULL;
 	GtkWidget *content = NULL;
 	GtkNotebook *notebook = NULL;
+	const gchar *view_name = NULL;
 	gchar *foldername = NULL;
+	gchar *sourcename = NULL;
 
 	foldername = kolab_plugin_ui_selected_folder_name (action,
 	                                                   shell_view);
@@ -410,11 +416,28 @@ kolab_plugin_ui_action_kolab_properties_cb (GtkAction *action,
 		return;
 	}
 
+	view_name = e_shell_view_get_name (shell_view);
+
+	if (g_strcmp0 (view_name, "mail") != 0) {
+		/* get the sourcename for display in dialogs
+		 * if we're in a PIM shell_view
+		 */
+		ESource *source = NULL;
+		gboolean is_source = FALSE;
+
+		is_source = kolab_plugin_ui_get_selected_source (shell_view,
+		                                                 &source);
+		if (is_source)
+			sourcename = g_strdup (e_source_peek_name (source));
+	}
+
 	uidata = kolab_folder_prop_ui_data_new ();
 
 	uidata->widgets->selected_folder =
-		e_kolab_plugin_util_ui_selected_folder_widget (foldername);
+		e_kolab_plugin_util_ui_selected_folder_widget (foldername,
+		                                               sourcename);
 	uidata->selected_folder = foldername;
+	uidata->selected_source = sourcename;
 
 	uidata->widgets->dialog =
 		gtk_dialog_new_with_buttons (_("Edit Kolab Folder Properties..."),
@@ -427,9 +450,11 @@ kolab_plugin_ui_action_kolab_properties_cb (GtkAction *action,
 
 	uidata->meta_ui_data = e_kolab_folder_metadata_ui_new ();
 	uidata->meta_ui_data->selected_folder = g_strdup (foldername);
+	uidata->meta_ui_data->selected_source = g_strdup (sourcename);
 
 	uidata->perm_ui_data = e_kolab_folder_permissions_ui_new ();
 	uidata->perm_ui_data->selected_folder = g_strdup (foldername);
+	uidata->perm_ui_data->selected_source = g_strdup (sourcename);
 
 	/* FIXME get account data here */
 	uidata->account = kolab_data_imap_account_new ();
