@@ -305,14 +305,60 @@ kolab_mail_side_cache_sql_query_object (KolabUtilSqliteDb *kdb,
 		/* check number of expected payload bytes */
 		mpart->length = (guint) sqlite3_column_int (sql_stmt,
 		                                            KOLAB_CONV_MAIL_SQLCOL_FIELD_LENGTH);
-		nbytes = (guint) sqlite3_column_bytes(sql_stmt,
-		                                      KOLAB_CONV_MAIL_SQLCOL_FIELD_DATA);
+		nbytes = (guint) sqlite3_column_bytes (sql_stmt,
+		                                       KOLAB_CONV_MAIL_SQLCOL_FIELD_DATA);
 		if (mpart->length != nbytes) {
-			g_set_error (&tmp_err,
-			             KOLAB_UTIL_ERROR,
-			             KOLAB_UTIL_ERROR_SQLITE_DB,
-			             _("Internal inconsistency detected: Invalid cache object has %i payload bytes, expected %i bytes, UID '%s', Folder '%s'"),
-			             mpart->length, nbytes, uid, foldername);
+			gchar *errmsg_0 = NULL;
+			gchar *errmsg_1 = NULL;
+			gchar *errmsg_2 = NULL;
+			gchar *errmsg = NULL;
+
+			/* Translators: This is the first sentence of a three-sentence message
+			 * of the form "Internal inconsistency detected: Invalid cache object, UID [uid],
+			 * Folder [foldername]. Expected payload size is [bytes] bytes. Actual payload
+			 * size is [bytes] bytes."
+			 */
+			errmsg_0 = g_strdup_printf (_("Internal inconsistency detected: Invalid cache object, UID '%s', Folder '%s'."),
+			                            uid, foldername);
+
+			/* Translators: This is the second sentence of a three-sentence message
+			 * of the form "Internal inconsistency detected: Invalid cache object, UID [uid],
+			 * Folder [foldername]. Expected payload size is [bytes] bytes. Actual payload
+			 * size is [bytes] bytes."
+			 */
+			errmsg_1 = g_strdup_printf (ngettext ("Expected payload size is %i byte.",
+			                                      "Expected payload size is %i bytes.",
+			                                      mpart->length),
+			                            mpart->length);
+
+			/* Translators: This is the third sentence of a three-sentence message
+			 * of the form "Internal inconsistency detected: Invalid cache object, UID [uid],
+			 * Folder [foldername]. Expected payload size is [bytes] bytes. Actual payload
+			 * size is [bytes] bytes."
+			 */
+			errmsg_2 = g_strdup_printf (ngettext ("Actual payload size is %i byte.",
+			                                      "Actual payload size is %i bytes.",
+			                                      nbytes),
+			                            nbytes);
+
+			/* Translators: This is the concatenated three-sentence message
+			 * of the form "Internal inconsistency detected: Invalid cache object,
+			 * UID [uid], Folder [foldername]. Expected payload size is [bytes]
+			 * bytes. Actual payload size is [bytes] bytes."
+			 * Reverse the ordering of the string arguments for RTL languages
+			 */
+			errmsg = g_strdup_printf (_("%1$s %2$s %3$s"),
+			                          errmsg_0, errmsg_1, errmsg_2);
+
+			g_set_error_literal (&tmp_err,
+			                     KOLAB_UTIL_ERROR,
+			                     KOLAB_UTIL_ERROR_SQLITE_DB,
+			                     errmsg);
+
+			g_free (errmsg_0);
+			g_free (errmsg_1);
+			g_free (errmsg_2);
+			g_free (errmsg);
 			break;
 		}
 		mpart->name = g_strdup ((gchar *) sqlite3_column_text (sql_stmt,
