@@ -27,11 +27,10 @@
 
 #include <libical/ical.h>
 
-#include <camel/camel-kolab-imapx-metadata.h>
-
 #include <libekolabutil/kolab-util-folder.h>
 
 #include "kolab-mail-summary.h"
+#include "camel-kolab-imapx-metadata.h"
 
 /*----------------------------------------------------------------------------*/
 /* local helpers */
