@@ -31,7 +31,7 @@
 
 #include <glib/gi18n-lib.h>
 
-#include <libecal/e-cal-time-util.h>
+#include <libecal/libecal.h>
 
 #include <libekolabutil/kolab-util-glib.h>
 #include <libekolabutil/kolab-util-folder.h>
@@ -1842,7 +1842,6 @@ kolab_mail_synchronizer_transaction_prepare (KolabMailSynchronizer *self,
 	GList *changed_uids_lst = NULL;
 	gchar *uid = NULL;
 	gchar *new_uid = NULL;
-	gchar *sourcename = NULL;
 	gboolean record_locally_created = FALSE;
 	gboolean uidval_changed = FALSE;
 	gboolean can_act = FALSE;
@@ -1910,13 +1909,9 @@ kolab_mail_synchronizer_transaction_prepare (KolabMailSynchronizer *self,
 		goto cleanup;
 	}
 
-	sourcename = kolab_util_backend_sourcename_new_from_foldername (foldername,
-	                                                                &tmp_err);
-	if (sourcename == NULL)
-		goto cleanup;
 	sync_id_ptr = kolab_settings_handler_get_value (priv->ksettings,
 	                                                KOLAB_SETTINGS_HANDLER_TBL_SYNCSTRATEGY,
-	                                                sourcename,
+	                                                foldername,
 	                                                &tmp_err);
 	if (tmp_err != NULL) {
 		sync_id = KOLAB_SYNC_STRATEGY_DEFAULT;
@@ -2197,8 +2192,6 @@ kolab_mail_synchronizer_transaction_prepare (KolabMailSynchronizer *self,
 		g_free (uid);
 	if (new_uid != NULL)
 		g_free (new_uid);
-	if (sourcename != NULL)
-		g_free (sourcename);
 	return can_act;
 }
 
