@@ -31,7 +31,8 @@
 
 #include <glib/gi18n-lib.h>
 
-#include <libedataserver/e-data-server-util.h>
+#include <libedataserver/libedataserver.h>
+#include <libekolabutil/kolab-util-camel.h>
 #include <libekolabutil/kolab-util-glib.h>
 
 #include "kolab-util-backend.h"
@@ -39,9 +40,10 @@
 
 /*----------------------------------------------------------------------------*/
 
-typedef struct _KolabSettingsHandlerPrivate KolabSettingsHandlerPrivate;
 struct _KolabSettingsHandlerPrivate
 {
+	CamelKolabIMAPXSettings *camel_settings;
+
 	gboolean is_configured;
 	gboolean is_up;
 
@@ -53,6 +55,11 @@ struct _KolabSettingsHandlerPrivate
 	GHashTable *sdata_tbl;
 };
 
+enum {
+	PROP_0,
+	PROP_CAMEL_SETTINGS
+};
+
 #define KOLAB_SETTINGS_HANDLER_PRIVATE(obj)  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KOLAB_TYPE_SETTINGS_HANDLER, KolabSettingsHandlerPrivate))
 
 G_DEFINE_TYPE (KolabSettingsHandler, kolab_settings_handler, G_TYPE_OBJECT)
@@ -80,11 +87,7 @@ static KolabSettingsHandlerGetFunc _kolab_settings_handler_char_get_funcs[] = {
 	kolab_settings_handler_char_get_func_camel_config_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CONFIG_DIR */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_ACCOUNT_DIR */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_ESOURCE_UID */
-	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_SERVER_NAME */
-	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_NAME */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_PASSWORD */
-	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_URI */
-	NULL  /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_PKCS11_USER_PIN */
 };
 
 static KolabSettingsHandlerCharSetFunc _kolab_settings_handler_char_set_funcs[] = {
@@ -93,21 +96,15 @@ static KolabSettingsHandlerCharSetFunc _kolab_settings_handler_char_set_funcs[]
 	kolab_settings_handler_char_set_func_camel_config_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CONFIG_DIR */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_ACCOUNT_DIR */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_ESOURCE_UID */
-	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_SERVER_NAME */
-	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_NAME */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_PASSWORD */
-	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_URI */
-	NULL  /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_PKCS11_USER_PIN */
 };
 
 static KolabSettingsHandlerGetFunc _kolab_settings_handler_uint_get_funcs[] = {
-	NULL, /* KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_CONTEXT */
-	NULL  /* KOLAB_SETTINGS_HANDLER_UINT_FIELD_TLS_VARIANT */
+	NULL /* KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_CONTEXT */
 };
 
 static KolabSettingsHandlerUintSetFunc _kolab_settings_handler_uint_set_funcs[] = {
-	kolab_settings_handler_uint_set_func_folder_context, /* KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_CONTEXT */
-	NULL  /* KOLAB_SETTINGS_HANDLER_UINT_FIELD_TLS_VARIANT */
+	kolab_settings_handler_uint_set_func_folder_context /* KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_CONTEXT */
 };
 
 /*----------------------------------------------------------------------------*/
@@ -312,16 +309,14 @@ kolab_settings_handler_uint_set_func_folder_context (KolabSettingsHandler *self,
 /*----------------------------------------------------------------------------*/
 
 static void
-kolab_settings_handler_init (KolabSettingsHandler *object)
+kolab_settings_handler_init (KolabSettingsHandler *self)
 {
-	KolabSettingsHandler *self = NULL;
 	KolabSettingsHandlerPrivate *priv = NULL;
 	gint ii = 0;
 
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (object));
+	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
 
-	self = KOLAB_SETTINGS_HANDLER (object);
-	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
+	priv = self->priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
 
 	for (ii = 0; ii < KOLAB_SETTINGS_HANDLER_CHAR_LAST_FIELD; ii++)
 		priv->sdata_char[ii] = NULL;
@@ -334,12 +329,12 @@ kolab_settings_handler_init (KolabSettingsHandler *object)
 
 	/* documenting initial settings (dumb fallback values) */
 	priv->sdata_uint[KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_CONTEXT] = KOLAB_FOLDER_CONTEXT_INVAL;
-	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_IMAP_PORT]  = 143;
-	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_IMAPS_PORT] = 993;
-	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_HTTP_PORT]  = 80;
-	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_HTTPS_PORT] = 443;
-	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_LDAP_PORT]  = 389;
-	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_LDAPS_PORT] = 636;
+	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_IMAP_PORT]  = KOLAB_SERVER_IMAP_PORT;
+	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_IMAPS_PORT] = KOLAB_SERVER_IMAPS_PORT;
+	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_HTTP_PORT]  = KOLAB_SERVER_HTTP_PORT;
+	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_HTTPS_PORT] = KOLAB_SERVER_HTTPS_PORT;
+	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_LDAP_PORT]  = KOLAB_SERVER_LDAP_PORT;
+	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_LDAPS_PORT] = KOLAB_SERVER_LDAPS_PORT;
 
 	priv->sdata_tbl = NULL;
 
@@ -347,16 +342,66 @@ kolab_settings_handler_init (KolabSettingsHandler *object)
 	priv->is_up = FALSE;
 }
 
+static void
+kolab_settings_handler_set_camel_settings (KolabSettingsHandler *ksettings,
+                                           CamelKolabIMAPXSettings *camel_settings)
+{
+	g_return_if_fail (CAMEL_IS_KOLAB_IMAPX_SETTINGS (camel_settings));
+	g_return_if_fail (ksettings->priv->camel_settings == NULL);
+
+	ksettings->priv->camel_settings = g_object_ref (camel_settings);
+}
+
+static void
+kolab_settings_handler_set_property (GObject *object,
+                                     guint property_id,
+                                     const GValue *value,
+                                     GParamSpec *pspec)
+{
+	switch (property_id) {
+		case PROP_CAMEL_SETTINGS:
+			kolab_settings_handler_set_camel_settings (
+				KOLAB_SETTINGS_HANDLER (object),
+				g_value_get_object (value));
+			return;
+		default:
+			break;
+	}
+
+	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+}
+
+static void
+kolab_settings_handler_get_property (GObject *object,
+                                     guint property_id,
+                                     GValue *value,
+                                     GParamSpec *pspec)
+{
+	switch (property_id) {
+		case PROP_CAMEL_SETTINGS:
+			g_value_set_object (
+				value,
+				kolab_settings_handler_get_camel_settings (
+				KOLAB_SETTINGS_HANDLER (object)));
+			return;
+		default:
+			break;
+	}
+
+	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+}
+
 static void
 kolab_settings_handler_dispose (GObject *object)
 {
-	/* KolabSettingsHandler *self = NULL; */
-	/* KolabSettingsHandlerPrivate *priv = NULL; */
+	KolabSettingsHandlerPrivate *priv = NULL;
 
-	/* self = KOLAB_SETTINGS_HANDLER (object); */
-	/* priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self); */
+	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (object);
 
-	/* TODO: Add dispose code here */
+	if (priv->camel_settings != NULL) {
+		g_object_unref (priv->camel_settings);
+		priv->camel_settings = NULL;
+	}
 
 	G_OBJECT_CLASS (kolab_settings_handler_parent_class)->dispose (object);
 }
@@ -390,8 +435,31 @@ kolab_settings_handler_class_init (KolabSettingsHandlerClass *klass)
 
 	g_type_class_add_private (klass, sizeof (KolabSettingsHandlerPrivate));
 
+	object_class->set_property = kolab_settings_handler_set_property;
+	object_class->get_property = kolab_settings_handler_get_property;
 	object_class->dispose = kolab_settings_handler_dispose;
 	object_class->finalize = kolab_settings_handler_finalize;
+
+	g_object_class_install_property (
+		object_class,
+		PROP_CAMEL_SETTINGS,
+		g_param_spec_object (
+			"camel-settings",
+			"Camel Settings",
+			"An authoritative CamelKolabIMAPXSettings",
+			CAMEL_TYPE_KOLAB_IMAPX_SETTINGS,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT_ONLY));
+}
+
+KolabSettingsHandler *
+kolab_settings_handler_new (CamelKolabIMAPXSettings *camel_settings)
+{
+	g_return_val_if_fail (CAMEL_IS_KOLAB_IMAPX_SETTINGS (camel_settings), NULL);
+
+	return g_object_new (
+		KOLAB_TYPE_SETTINGS_HANDLER,
+		"camel-settings", camel_settings, NULL);
 }
 
 /*----------------------------------------------------------------------------*/
@@ -503,6 +571,14 @@ kolab_settings_handler_shutdown (KolabSettingsHandler *self,
 /*----------------------------------------------------------------------------*/
 /* config item getters/setters */
 
+CamelKolabIMAPXSettings *
+kolab_settings_handler_get_camel_settings (KolabSettingsHandler *self)
+{
+	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
+
+	return self->priv->camel_settings;
+}
+
 /**
  * kolab_settings_handler_set_char_field:
  * @self: a #KolabSettingsHandler instance
