@@ -29,7 +29,7 @@
 
 #include <glib/gi18n-lib.h>
 
-#include <libedataserver/e-data-server-util.h>
+#include <libedataserver/libedataserver.h>
 
 #include "kolab-util-error.h"
 #include "kolab-util-glib.h"
